@@ -188,7 +188,7 @@ inspectDigests <- function(
 
   small_digest <- substr(digests, 1, 6)
  
-  txomeInfo <- sapply(digests, getTxomeInfo, prefer, quiet=TRUE)
+  txomeInfo <- lapply(digests, getTxomeInfo, prefer, quiet=TRUE)
 
   # this is the tibble the function will return
   out <- tibble(
@@ -315,7 +315,7 @@ updateMetadata <- function(
   )
 
   # pull out the txomeInfo for each index
-  txomeInfo <- sapply(digests, getTxomeInfo, prefer=c("txome","txpdata","precomputed"), quiet = TRUE)
+  txomeInfo <- lapply(digests, getTxomeInfo, prefer=c("txome","txpdata","precomputed"), quiet = TRUE)
 
   # empty GRanges, add to this per index / txpData in loop below
   ranges_to_add <- GenomicRanges::GRanges()
